<?php
/* --------------------------------------------------------------
   EmailAttachment.inc.php 2015-01-29 gm
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2015 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

MainFactory::load_class('EmailAttachmentInterface');

/**
 * Class EmailAttachment
 *
 * Email attachment will serve as the path to the file that needs to be attached
 * (located on the server).
 *
 * @category   System
 * @package    Email
 * @subpackage Entities
 */
class EmailAttachment implements EmailAttachmentInterface
{
	/**
	 * @var string
	 */
	protected $path;
	
	/**
	 * @var string
	 */
	protected $name;
	
	
	/**
	 * Constructor
	 *
	 * Entity representing an email attachment.
	 *
	 * @param AttachmentPathInterface $path (optional)
	 * @param AttachmentNameInterface $name (optional)
	 */
	public function __construct(AttachmentPathInterface $path = null, AttachmentNameInterface $name = null)
	{
		$this->path = str_replace(DIR_FS_CATALOG, '', (string)$path);
		$this->name = (string)$name;
	}
	
	
	/**
	 * Path Setter
	 *
	 * @param AttachmentPathInterface $path
	 */
	public function setPath(AttachmentPathInterface $path)
	{
		$this->path = str_replace(DIR_FS_CATALOG, '', (string)$path);
	}
	
	
	/**
	 * Path Getter
	 *
	 * @return AttachmentPathInterface
	 */
	public function getPath($absolutePath = true)
	{
		$path = ($absolutePath) ? DIR_FS_CATALOG . $this->path : $this->path;
		
		return ($path !== DIR_FS_CATALOG) ? MainFactory::create('AttachmentPath', $path) : null;
	}
	
	
	/**
	 * Name Setter
	 *
	 * @param AttachmentNameInterface $name
	 */
	public function setName(AttachmentNameInterface $name)
	{
		$this->name = (string)$name;
	}
	
	
	/**
	 * Name Getter
	 *
	 * @return AttachmentNameInterface
	 */
	public function getName()
	{
		return MainFactory::create('AttachmentName', $this->name);
	}
}