<?php
/* --------------------------------------------------------------
   StaticGXCoreLoader.inc.php 2015-01-30 gm
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2015 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/


/**
 * Class StaticGXCoreLoader
 *
 * This class is for static use only.
 * Usage example: $customerService = StaticGXCoreLoader::getService('Customer');
 * 
 * @category System
 * @package GXCoreLoader
 */
class StaticGXCoreLoader
{
	/**
	 * @var GXCoreLoaderInterface
	 */
	protected static $gxCoreLoader = null;


	/**
	 * @throws BadFunctionCallException
	 */
	public function __construct()
	{
		throw new BadFunctionCallException('This class is for static use only.');
	}


	/**
	 * @param string $serviceName
	 * @return object
	 */
	public static function getService($serviceName)
	{
		$gxCoreLoader = self::_getGXCoreLoader();
		$service = $gxCoreLoader->getService($serviceName);
		return $service;
	}


	/**
	 * @return GXCoreLoaderInterface
	 */
	protected static function _getGXCoreLoader()
	{
		if(self::$gxCoreLoader === NULL)
		{
			$gxCoreLoaderSettings = MainFactory::create('GXCoreLoaderSettings');
			self::$gxCoreLoader = MainFactory::create('GXCoreLoader', $gxCoreLoaderSettings);
		}
		return self::$gxCoreLoader;
	}
}
