<?php
/* --------------------------------------------------------------
   AbstractCollection.inc.php 2015-01-24 gm
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2015 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/


/**
 * Class AbstractCollection
 * 
 * @category System
 * @package Shared
 */
abstract class AbstractCollection
{
	/**
	 * @var array
	 */
	protected $collectionContentArray = array();


	/**
	 * Class Constructor
	 */
	public function __construct()
	{
		$argsArray = func_get_args();

		foreach($argsArray as $argsItem)
		{
			try
			{
				$this->_add($argsItem);
			}
			catch(InvalidArgumentException $e)
			{
				throw $e;
			}
		}
	}


	/**
	 * @return int
	 */
	public function count()
	{
		return sizeof($this->collectionContentArray);
	}


	/**
	 * TODO rename to toArray()
	 * 
	 * @return array
	 */
	public function getArray()
	{
		return $this->collectionContentArray;
	}


	/**
	 * @param $p_index
	 *
	 * @return mixed
	 */
	public function getItem($p_index)
	{
		if(is_numeric($p_index) == false)
		{
			throw new InvalidArgumentException('Given $p_index not numeric');
		}

		if($p_index < 0 || $p_index >= sizeof($this->collectionContentArray))
		{
			throw new OutOfBoundsException('$p_index is out of bounds');
		}
		return $this->collectionContentArray[$p_index];
	}


	/**
	 * @return bool
	 */
	public function isEmpty()
	{
		return empty($this->collectionContentArray);
	}
	

	/**
	 * @param mixed $item
	 */
	protected function _add($item)
	{
		if($this->_itemIsValid($item) == false)
		{
			$exceptionText = $this->_getExceptionText();
			throw new InvalidArgumentException($exceptionText);
		}
		else
		{
			$this->collectionContentArray[] = $item;
		}
	}


	/**
	 * @param mixed $dataItem
	 *
	 * @return bool
	 */
	protected function _itemIsValid($dataItem)
	{
		if(is_object($dataItem) == false)
		{
			return false;
		}

		if(is_a($dataItem, $this->_getValidType()) == false)
		{
			return false;
		}
		
		return true;
	}


	/**
	 * @return string
	 */
	protected function _getExceptionText()
	{
		return 'Given item has invalid type ('. $this->_getValidType() .' needed)';
	}


	/**
	 * @return string
	 */
	abstract protected function _getValidType();
}
 